import 'package:flutter/material.dart';
import 'package:verttice_ui/verttice_ui.dart';

enum ThemedLocale {
  en,
  enGB,
  enUS,
  heIL,
}

final Map<ThemedLocale, Locale> themedLocalToLocale = {
  ThemedLocale.en: const Locale(
    'en',
  ),
  ThemedLocale.enUS: const Locale('en', 'US'),
  ThemedLocale.enGB: const Locale('en', 'GB'),
  ThemedLocale.heIL: const Locale('he', 'IL'),
};

class ThemedLocaleManager {
  ThemedLocale _locale = ThemedLocale.en;
  Map<String, ThemedLocaleKey> _localeKeys = {};
  List<ThemedLocale> _appSupportLocale = [ThemedLocale.en];
  void initLocale(ThemedLocale locale) {
    _locale = locale;
  }

  void setAppSupportLocale(List<ThemedLocale> appSupportLocale) =>
      _appSupportLocale = !appSupportLocale.contains(ThemedLocale.en)
          ? [...appSupportLocale, ThemedLocale.en]
          : _appSupportLocale;
  List<ThemedLocale> get appSupportLocale => _appSupportLocale;

  Locale get appLocale => themedLocalToLocale[_locale]!;

  ThemedLocale get locale => _locale;

  void setLocaleKeys(Map<String, ThemedLocaleKey> localeKeys) {
    _localeKeys = localeKeys;
  }

  String key(String key) {
    if (_localeKeys[key] != null) {
      return _localeKeys[key]!.byLocale(_locale);
    }
    throw 'Themed Locale: Key not found';
  }
}
