// 🐦 Flutter imports:
import "package:flutter/gestures.dart";
import "package:flutter/material.dart";

// 📦 Package imports:
import "package:url_launcher/url_launcher.dart";
import "package:validators/validators.dart" as valid;

class ClickableText extends StatefulWidget {
  final String text;
  final TextStyle? style;

  const ClickableText(
    this.text, {
    Key? key,
    this.style,
  }) : super(key: key);

  @override
  State<ClickableText> createState() => _ClickableTextState();
}

class _ClickableTextState extends State<ClickableText> {
  @override
  Widget build(BuildContext context) {
    TextStyle linkStyle = const TextStyle(color: Colors.blue);
    final List<String> textList = widget.text.split(" ");
    return RichText(
      text: TextSpan(
        style: widget.style,
        children: textList.map<TextSpan>((e) {
          if (valid.isEmail(e) || valid.isURL(e)) {
            return TextSpan(
              text: "Click here for more info ",
              style: linkStyle,
              recognizer: TapGestureRecognizer()
                ..onTap = () {
                  _launchURL(context, e);
                },
            );
          }
          return TextSpan(text: "$e ");
        }).toList(),
      ),
    );
  }

  void _launchURL(BuildContext context, String url) async {
    if (await canLaunchUrl(Uri.parse(url))) {
      await launchUrl(Uri.parse(url));
    }
  }
}
