// 🐦 Flutter imports:
import "package:flutter/material.dart";

// 📦 Package imports:

// 🌎 Project imports:
import 'package:verttice_ui/verttice_ui.dart';

class ThemedAppBar extends StatelessWidget with PreferredSizeWidget {
  final String? title;
  final List<Widget>? actions;
  final Color? backgroundColor;
  final bool navigateBackButton;
  final Widget? leading;
  final double? appBarHeight;
  final TextStyle? titleTextStyle;

  const ThemedAppBar({
    Key? key,
    required this.navigateBackButton,
    this.title,
    this.titleTextStyle,
    this.actions,
    this.backgroundColor,
    this.leading,
    this.appBarHeight,
  }) : super(key: key);

  @override
  Widget build(BuildContext context) {
    return AppBar(
      toolbarHeight: appBarHeight ??
          (ThemedPlatform.isAndroidNativeApp || ThemedPlatform.isIOSNativeApp
              ? 100
              : 55),
      backgroundColor: backgroundColor,
      title: title != null
          ? LayoutBuilder(builder: (context, constraints) {
              return Align(
                alignment: Alignment.centerLeft,
                child: Padding(
                  padding: const EdgeInsets.only(left: 8),
                  child: SizedBox(
                    width: constraints.maxWidth - 40,
                    child: Text(
                      title!,
                      maxLines: 3,
                      softWrap: true,
                      overflow: TextOverflow.fade,
                      style: const TextStyle(
                        fontSize: 15,
                      ).merge(titleTextStyle),
                    ),
                  ),
                ),
              );
            })
          : null,
      leading: leading ??
          (!navigateBackButton
              ? null
              : Align(
                  alignment: Alignment.centerLeft,
                  child: ThemedIconButton(
                    onPressed: () => Navigator.pop(context),
                    icon: ThemedIcons.arrowBack(),
                  ),
                )),
      actions: actions,
      automaticallyImplyLeading: false,
    );
  }

  @override
  Size get preferredSize => Size(
      double.infinity,
      appBarHeight ??
          (ThemedPlatform.isAndroidNativeApp || ThemedPlatform.isIOSNativeApp
              ? 100
              : 55));
}
