// 🐦 Flutter imports:
import 'package:flutter/material.dart';

// 📦 Package imports:
import 'package:flutter_quill/flutter_quill.dart' hide Text;

// 🌎 Project imports:
import 'package:verttice_ui/verttice_ui.dart';
import 'package:flutter_quill/extensions.dart' as base;

import 'editor_image_web.dart';
import 'editor_video_player_web.dart';
import 'editor_youtube_player_web.dart';

List<EmbedBuilder> embedBuilderWeb() => [
      ImageEmbedBuilderWeb(),
      VideoEmbedBuilderWeb(),
    ];

class ImageEmbedBuilderWeb implements EmbedBuilder {
  @override
  String get key => BlockEmbed.imageType;

  @override
  Widget build(
    BuildContext context,
    QuillController controller,
    base.Embed node,
    bool readOnly,
  ) {
    final imageUrl = node.value.data;
    return EditorImageWeb(
      imageUrl: imageUrl,
    );
  }
}

class VideoEmbedBuilderWeb implements EmbedBuilder {
  @override
  String get key => BlockEmbed.videoType;

  @override
  Widget build(
    BuildContext context,
    QuillController controller,
    base.Embed node,
    bool readOnly,
  ) {
    final videoUrl = node.value.data;
    if (videoUrl.contains('youtube.com') || videoUrl.contains('youtu.be')) {
      return TransparentPointer(
        child: EditorYoutubePlayerWeb(
          videoUrl: videoUrl,
          readOnly: readOnly,
        ),
      );
    }

    return EditorVideoPlayerWeb(
      videoUrl: videoUrl,
      readOnly: readOnly,
    );
  }
}
